﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/ec2/EC2_EXPORTS.h>

namespace Aws {
namespace EC2 {
namespace Model {
enum class InstanceStorageEncryptionSupport { NOT_SET, unsupported, required };

namespace InstanceStorageEncryptionSupportMapper {
AWS_EC2_API InstanceStorageEncryptionSupport GetInstanceStorageEncryptionSupportForName(const Aws::String& name);

AWS_EC2_API Aws::String GetNameForInstanceStorageEncryptionSupport(InstanceStorageEncryptionSupport value);
}  // namespace InstanceStorageEncryptionSupportMapper
}  // namespace Model
}  // namespace EC2
}  // namespace Aws
